@@ -6,14 +6,15 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: OAEP.pm,v 1.20 2001/04/09 23:07:28 vipul Exp $
+## $Id: OAEP.pm,v 1.21 2001/04/17 19:48:38 vipul Exp $
 
 use lib "/home/vipul/PERL/crypto/rsa/lib";
 package Crypt::RSA::ES::OAEP; 
 use strict;
 use vars qw(@ISA $VERSION);
+use Crypt::Random          qw(makerandom_octet);
 use Crypt::RSA::Errorhandler; 
-use Crypt::RSA::DataFormat qw(bitsize os2ip i2osp octet_xor generate_random_octet mgf1 octet_len);
+use Crypt::RSA::DataFormat qw(bitsize os2ip i2osp octet_xor mgf1 octet_len);
 use Crypt::RSA::Primitives;
 use Crypt::RSA::Debug      qw(debug);
 use Digest::SHA1           qw(sha1);
@@ -21,7 +22,7 @@ use Math::Pari             qw(floor);
 use Sort::Versions         qw(versioncmp);
 use Carp;
 @ISA = qw(Crypt::RSA::Errorhandler);
-($VERSION)  = '$Revision: 1.20 $' =~ /\s(\d+\.\d+)\s/; 
+($VERSION)  = '$Revision: 1.21 $' =~ /\s(\d+\.\d+)\s/; 
 
 sub new { 
     my ($class, %params) = @_;
@@ -84,7 +85,7 @@ sub encode {
     }
     my $phash = $self->hash ($P);
     my $db = $phash . $PS . chr(1) . $M; 
-    my $seed = generate_random_octet ($hlen);
+    my $seed = makerandom_octet (Length => $hlen);
     my $dbmask = $self->mgf ($seed, $emlen-$hlen);
     my $maskeddb = octet_xor ($db, $dbmask);
     my $seedmask = $self->mgf ($maskeddb, $hlen);
